/*
 * (c) Copyright 2007-2009 by Volker Bergmann. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, is permitted under the terms of the
 * GNU General Public License.
 *
 * For redistributing this software or a derivative work under a license other
 * than the GPL-compatible Free Software License as defined by the Free
 * Software Foundation or approved by OSI, you must first obtain a commercial
 * license to this software product from Volker Bergmann.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * WITHOUT A WARRANTY OF ANY KIND. ALL EXPRESS OR IMPLIED CONDITIONS,
 * REPRESENTATIONS AND WARRANTIES, INCLUDING ANY IMPLIED WARRANTY OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT, ARE
 * HEREBY EXCLUDED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

package org.databene.regex;

/**
 * Represents a regular expression part composed of a SubPattern and a Quantifier.<br/>
 * <br/>
 * Created: 18.08.2006 19:11:31
 */
public class Factor {

    /** The sub pattern */
    private Object atom;

    /** The quantifier */
    private Quantifier quantifier;

    // constructors ----------------------------------------------------------------------------------------------------

    public Factor(Object pattern) {
        this(pattern, 1, 1);
    }

    public Factor(Object atom, int minQuantity, Integer maxQuantity) {
        this(atom, new Quantifier(minQuantity, maxQuantity));
    }

    public Factor(Object atom, Quantifier quantifier) {
        this.atom = atom;
        this.quantifier = quantifier;
    }

    // properties ------------------------------------------------------------------------------------------------------

    /** Returns the atom */
    public Object getAtom() {
        return atom;
    }

    /** Returns the represented quantifier */
    public Quantifier getQuantifier() {
        return quantifier;
    }

    // java.lang.Object overrides --------------------------------------------------------------------------------------

    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public boolean equals(Object o) {
        if (this == o)
            return true;
        if (o == null || getClass() != o.getClass())
            return false;
        final Factor regexPart = (Factor) o;
        if (!atom.equals(regexPart.atom))
            return false;
        return quantifier.equals(regexPart.quantifier);
    }

    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public int hashCode() {
        return 29 * atom.hashCode() + quantifier.hashCode();
    }

    /**
     * @see java.lang.Object#equals(Object)
     */
    @Override
    public String toString() {
        return atom.toString() + quantifier.toString();
    }
    
}
